==> vtk6-6.3.0-9-aarch64.pkg.tar.xz: vtk/vtkDistanceRepresentation2D.java <==
// java wrapper for vtkDistanceRepresentation2D object
//

package vtk;
import vtk.*;

public class vtkDistanceRepresentation2D extends vtkDistanceRepresentation
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native double GetDistance_2();
  public double GetDistance()
    { return GetDistance_2(); }

  private native void GetPoint1WorldPosition_3(double id0[]);
  public void GetPoint1WorldPosition(double id0[])
    { GetPoint1WorldPosition_3(id0); }

  private native void GetPoint2WorldPosition_4(double id0[]);
  public void GetPoint2WorldPosition(double id0[])
    { GetPoint2WorldPosition_4(id0); }

  private native void SetPoint1WorldPosition_5(double id0[]);
  public void SetPoint1WorldPosition(double id0[])
    { SetPoint1WorldPosition_5(id0); }

  private native void SetPoint2WorldPosition_6(double id0[]);
  public void SetPoint2WorldPosition(double id0[])
    { SetPoint2WorldPosition_6(id0); }

  private native void SetPoint1DisplayPosition_7(double id0[]);
  public void SetPoint1DisplayPosition(double id0[])
    { SetPoint1DisplayPosition_7(id0); }

  private native void SetPoint2DisplayPosition_8(double id0[]);
  public void SetPoint2DisplayPosition(double id0[])
    { SetPoint2DisplayPosition_8(id0); }

  private native void GetPoint1DisplayPosition_9(double id0[]);
  public void GetPoint1DisplayPosition(double id0[])
    { GetPoint1DisplayPosition_9(id0); }

  private native void GetPoint2DisplayPosition_10(double id0[]);
  public void GetPoint2DisplayPosition(double id0[])
    { GetPoint2DisplayPosition_10(id0); }

  private native long GetAxis_11();
  public vtkAxisActor2D GetAxis() {
    long temp = GetAxis_11();

    if (temp == 0) return null;
    return (vtkAxisActor2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetAxisProperty_12();
  public vtkProperty2D GetAxisProperty() {
    long temp = GetAxisProperty_12();

    if (temp == 0) return null;
    return (vtkProperty2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void BuildRepresentation_13();
  public void BuildRepresentation()
    { BuildRepresentation_13(); }

  private native void ReleaseGraphicsResources_14(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_14(id0); }

  private native int RenderOverlay_15(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_15(id0); }

  private native int RenderOpaqueGeometry_16(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_16(id0); }

  public vtkDistanceRepresentation2D() { super(); }

  public vtkDistanceRepresentation2D(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-14-aarch64.pkg.tar.xz: vtk/vtkDistanceRepresentation2D.java <==
// java wrapper for vtkDistanceRepresentation2D object
//

package vtk;
import vtk.*;

public class vtkDistanceRepresentation2D extends vtkDistanceRepresentation
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native double GetDistance_2();
  public double GetDistance()
    { return GetDistance_2(); }

  private native void GetPoint1WorldPosition_3(double id0[]);
  public void GetPoint1WorldPosition(double id0[])
    { GetPoint1WorldPosition_3(id0); }

  private native void GetPoint2WorldPosition_4(double id0[]);
  public void GetPoint2WorldPosition(double id0[])
    { GetPoint2WorldPosition_4(id0); }

  private native void SetPoint1WorldPosition_5(double id0[]);
  public void SetPoint1WorldPosition(double id0[])
    { SetPoint1WorldPosition_5(id0); }

  private native void SetPoint2WorldPosition_6(double id0[]);
  public void SetPoint2WorldPosition(double id0[])
    { SetPoint2WorldPosition_6(id0); }

  private native void SetPoint1DisplayPosition_7(double id0[]);
  public void SetPoint1DisplayPosition(double id0[])
    { SetPoint1DisplayPosition_7(id0); }

  private native void SetPoint2DisplayPosition_8(double id0[]);
  public void SetPoint2DisplayPosition(double id0[])
    { SetPoint2DisplayPosition_8(id0); }

  private native void GetPoint1DisplayPosition_9(double id0[]);
  public void GetPoint1DisplayPosition(double id0[])
    { GetPoint1DisplayPosition_9(id0); }

  private native void GetPoint2DisplayPosition_10(double id0[]);
  public void GetPoint2DisplayPosition(double id0[])
    { GetPoint2DisplayPosition_10(id0); }

  private native long GetAxis_11();
  public vtkAxisActor2D GetAxis() {
    long temp = GetAxis_11();

    if (temp == 0) return null;
    return (vtkAxisActor2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetAxisProperty_12();
  public vtkProperty2D GetAxisProperty() {
    long temp = GetAxisProperty_12();

    if (temp == 0) return null;
    return (vtkProperty2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void BuildRepresentation_13();
  public void BuildRepresentation()
    { BuildRepresentation_13(); }

  private native void ReleaseGraphicsResources_14(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_14(id0); }

  private native int RenderOverlay_15(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_15(id0); }

  private native int RenderOpaqueGeometry_16(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_16(id0); }

  public vtkDistanceRepresentation2D() { super(); }

  public vtkDistanceRepresentation2D(long id) { super(id); }
  public native long   VTKInit();

}
